@@ -1,9 +1,8 @@
 package bbolt
 
 import (
+	"crypto/rand"
 	"fmt"
-	"io/ioutil"
-	"math/rand"
 	"os"
 	"path/filepath"
 	"testing"
@@ -12,7 +11,7 @@ import (
 func createDb(t *testing.T) (*DB, func()) {
 	// First, create a temporary directory to be used for the duration of
 	// this test.
-	tempDirName, err := ioutil.TempDir("", "bboltmemtest")
+	tempDirName, err := os.MkdirTemp("", "bboltmemtest")
 	if err != nil {
 		t.Fatalf("error creating temp dir: %v", err)
 	}
@@ -47,7 +46,9 @@ func createAndPutKeys(t *testing.T) {
 			}
 
 			var key [16]byte
-			rand.Read(key[:])
+			if _, err := rand.Read(key[:]); err != nil {
+				return err
+			}
 			if err := nodes.Put(key[:], nil); err != nil {
 				return err
 			}
